==> openmm-6.0-py33_3.tar.bz2: include/openmm/reference/ReferenceBondIxn.h <==

/* Portions copyright (c) 2006 Stanford University and Simbios.
 * Contributors: Pande Group
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject
 * to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS, CONTRIBUTORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

#ifndef __ReferenceBondIxn_H__
#define __ReferenceBondIxn_H__

#include "RealVec.h"
#include "openmm/internal/windowsExport.h"
#include <vector>

// ---------------------------------------------------------------------------------------

class OPENMM_EXPORT ReferenceBondIxn {

   private:

   public:

      /**---------------------------------------------------------------------------------------
      
         Constructor
      
         --------------------------------------------------------------------------------------- */

       ReferenceBondIxn( );

      /**---------------------------------------------------------------------------------------
      
         Destructor
      
         --------------------------------------------------------------------------------------- */

       ~ReferenceBondIxn( );

      /**---------------------------------------------------------------------------------------
      
         Calculate Bond Ixn -- virtual method
      
         @param atomIndices      bond indices
         @param atomCoordinates  atom coordinates
         @param parameters       parameters
         @param forces           force array (forces added)
         @param totalEnergy      if not null, the energy will be added to this
      
         --------------------------------------------------------------------------------------- */
      
      virtual void calculateBondIxn( int* atomIndices, std::vector<OpenMM::RealVec>& atomCoordinates,
                                    RealOpenMM* parameters, std::vector<OpenMM::RealVec>& forces,
                                    RealOpenMM* totalEnergy ) const;
      
      /**---------------------------------------------------------------------------------------
      
         Get normed dot product between two vectors
      
         @param  vector1            first vector
         @param  vector2            second vector
         @param  hasREntry          if set, then vector1[ReferenceForce::RIndex] = norm of vector;
                                    defaults to 0
      
         @return dot product
      
         --------------------------------------------------------------------------------------- */
      
      RealOpenMM getNormedDotProduct( RealOpenMM* vector1, RealOpenMM* vector2, int hasREntry ) const;
      
      /**---------------------------------------------------------------------------------------
      
         Get angle between two vectors
      
         @param  vector1            first vector
         @param  vector2            second vector
         @param  outputDotProduct   cosine of angle between two vectors (optional)
         @param  hasREntry          if set, then vector1[ReferenceForce::R2Index] = square norm of vector;
                                    defaults to 0
      
         @return cosine of angles in radians
      
         --------------------------------------------------------------------------------------- */
      
      RealOpenMM getAngleBetweenTwoVectors( RealOpenMM* vector1, RealOpenMM* vector2, 
                                            RealOpenMM* outputDotProduct, int hasREntry ) const;
      
      /**---------------------------------------------------------------------------------------
      
         Get dihedral angle between two vectors
      
         @param  vector1            first vector
         @param  vector2            second vector
         @param  vector3            third vector
         @param  outputCrossProduct output cross product vectors
         @param  cosineOfAngle      cosine of angle (output)
         @param  signVector         vector to test sign (optional)
         @param  signOfAngle        sign of angle (output) (optional)
         @param  hasREntry          if set, then vector1[ReferenceForce::R2Index] = square norm of vector
                                    defaults to 0
      
         @return cosine of angles in radians
      
         --------------------------------------------------------------------------------------- */
      
      RealOpenMM getDihedralAngleBetweenThreeVectors( RealOpenMM* vector1, RealOpenMM* vector2, 
                                                      RealOpenMM* vector3, RealOpenMM** outputCrossProduct, 
                                                      RealOpenMM* cosineOfAngle, RealOpenMM* signVector, 
                                                      RealOpenMM* signOfAngle, int hasREntry ) const;
      
};

// ---------------------------------------------------------------------------------------

#endif // __ReferenceBondIxn_H__

==> openmm-6.2-py27_0.tar.bz2: include/openmm/reference/ReferenceBondIxn.h <==

/* Portions copyright (c) 2006 Stanford University and Simbios.
 * Contributors: Pande Group
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject
 * to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS, CONTRIBUTORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

#ifndef __ReferenceBondIxn_H__
#define __ReferenceBondIxn_H__

#include "RealVec.h"
#include "openmm/internal/windowsExport.h"
#include <vector>

// ---------------------------------------------------------------------------------------

class OPENMM_EXPORT ReferenceBondIxn {

   private:

   public:

      /**---------------------------------------------------------------------------------------
      
         Constructor
      
         --------------------------------------------------------------------------------------- */

       ReferenceBondIxn( );

      /**---------------------------------------------------------------------------------------
      
         Destructor
      
         --------------------------------------------------------------------------------------- */

       ~ReferenceBondIxn( );

      /**---------------------------------------------------------------------------------------
      
         Calculate Bond Ixn -- virtual method
      
         @param atomIndices      bond indices
         @param atomCoordinates  atom coordinates
         @param parameters       parameters
         @param forces           force array (forces added)
         @param totalEnergy      if not null, the energy will be added to this
      
         --------------------------------------------------------------------------------------- */
      
      virtual void calculateBondIxn( int* atomIndices, std::vector<OpenMM::RealVec>& atomCoordinates,
                                    RealOpenMM* parameters, std::vector<OpenMM::RealVec>& forces,
                                    RealOpenMM* totalEnergy ) const;
      
      /**---------------------------------------------------------------------------------------
      
         Get normed dot product between two vectors
      
         @param  vector1            first vector
         @param  vector2            second vector
         @param  hasREntry          if set, then vector1[ReferenceForce::RIndex] = norm of vector;
                                    defaults to 0
      
         @return dot product
      
         --------------------------------------------------------------------------------------- */
      
      static RealOpenMM getNormedDotProduct( RealOpenMM* vector1, RealOpenMM* vector2, int hasREntry );
      
      /**---------------------------------------------------------------------------------------
      
         Get angle between two vectors
      
         @param  vector1            first vector
         @param  vector2            second vector
         @param  outputDotProduct   cosine of angle between two vectors (optional)
         @param  hasREntry          if set, then vector1[ReferenceForce::R2Index] = square norm of vector;
                                    defaults to 0
      
         @return cosine of angles in radians
      
         --------------------------------------------------------------------------------------- */
      
      static RealOpenMM getAngleBetweenTwoVectors( RealOpenMM* vector1, RealOpenMM* vector2, 
                                                   RealOpenMM* outputDotProduct, int hasREntry );
      
      /**---------------------------------------------------------------------------------------
      
         Get dihedral angle between two vectors
      
         @param  vector1            first vector
         @param  vector2            second vector
         @param  vector3            third vector
         @param  outputCrossProduct output cross product vectors
         @param  cosineOfAngle      cosine of angle (output)
         @param  signVector         vector to test sign (optional)
         @param  signOfAngle        sign of angle (output) (optional)
         @param  hasREntry          if set, then vector1[ReferenceForce::R2Index] = square norm of vector
                                    defaults to 0
      
         @return cosine of angles in radians
      
         --------------------------------------------------------------------------------------- */
      
      static RealOpenMM getDihedralAngleBetweenThreeVectors( RealOpenMM* vector1, RealOpenMM* vector2, 
                                                             RealOpenMM* vector3, RealOpenMM** outputCrossProduct, 
                                                             RealOpenMM* cosineOfAngle, RealOpenMM* signVector, 
                                                             RealOpenMM* signOfAngle, int hasREntry );
      
};

// ---------------------------------------------------------------------------------------

#endif // __ReferenceBondIxn_H__
